ElementContext

Trait ElementContext 

pub trait ElementContext {
    // Required methods
    fn opaque_element(&self) -> Option<OpaqueElement>;
    fn opaque_parent(&self) -> Option<OpaqueNode>;
    fn get_attr(
        &self,
        attr: &LocalName,
        namespace: &Namespace,
    ) -> Option<String>;
    fn get_tree_counting_result(
        &self,
        caches: &mut TreeCountingCaches,
    ) -> TreeCountingResult;
}
Provides element-level context needed during style computation.

Required Methods

fn opaque_element(&self) -> Option<OpaqueElement>

Opaque handle to the element.

fn opaque_parent(&self) -> Option<OpaqueNode>

Opaque handle to the element’s parent node.

fn get_attr(&self, attr: &LocalName, namespace: &Namespace) -> Option<String>

Return the value of the given custom attribute if it exists.

fn get_tree_counting_result( &self, caches: &mut TreeCountingCaches, ) -> TreeCountingResult

Traverse the siblings of the element, returning the element’s sibling-index() and sibling-count(). Also populates caches with the sibling-index() and sibling-count() values for all siblings of this element.

Implementors